searchData={"items":[{"type":"module","title":"BoldTranscriptsEx","doc":"BoldTranscriptsEx is a library for working with transcripts in the Bold Video platform.\n\nIt provides functionality for:\n- Converting transcripts from various vendors (AssemblyAI, Deepgram) to Bold format\n- Generating WebVTT subtitles from Bold transcripts\n- Working with chapter markers in WebVTT format","ref":"BoldTranscriptsEx.html"},{"type":"function","title":"BoldTranscriptsEx.chapters_to_webvtt/1","doc":"Converts a list of chapters into WebVTT format.","ref":"BoldTranscriptsEx.html#chapters_to_webvtt/1"},{"type":"function","title":"Parameters - BoldTranscriptsEx.chapters_to_webvtt/1","doc":"- `chapters`: A list of maps, each containing `:start`, `:end`, and `:title` keys,\n  or `:assemblyai` and a transcript map for AssemblyAI format.","ref":"BoldTranscriptsEx.html#chapters_to_webvtt/1-parameters"},{"type":"function","title":"Returns - BoldTranscriptsEx.chapters_to_webvtt/1","doc":"- When given a list of chapters: A string in WebVTT format\n- When given `:assemblyai` format: `{:ok, string}` or `{:error, reason}`","ref":"BoldTranscriptsEx.html#chapters_to_webvtt/1-returns"},{"type":"function","title":"Examples - BoldTranscriptsEx.chapters_to_webvtt/1","doc":"iex> chapters = [%{start: \"0:03\", end: \"0:16\", title: \"Chapter 1\"}]\n    iex> BoldTranscriptsEx.chapters_to_webvtt(chapters)\n    \"WEBVTT\\n\\n1\\n00:00:03.000 --> 00:00:16.000\\nChapter 1\"\n\n    iex> transcript = %{\"chapters\" => [%{\"start\" => 3000, \"end\" => 16000, \"gist\" => \"Chapter 1\"}]}\n    iex> BoldTranscriptsEx.chapters_to_webvtt(:assemblyai, transcript)\n    {:ok, \"WEBVTT\\n\\n1\\n00:00:03.000 --> 00:00:16.000\\nChapter 1\"}","ref":"BoldTranscriptsEx.html#chapters_to_webvtt/1-examples"},{"type":"function","title":"BoldTranscriptsEx.chapters_to_webvtt/2","doc":"","ref":"BoldTranscriptsEx.html#chapters_to_webvtt/2"},{"type":"function","title":"BoldTranscriptsEx.convert/3","doc":"Converts a transcript from a specific service to Bold format.","ref":"BoldTranscriptsEx.html#convert/3"},{"type":"function","title":"Parameters - BoldTranscriptsEx.convert/3","doc":"- `service`: The service that generated the transcript (e.g., `:assemblyai`, `:deepgram`)\n- `transcript_data`: The JSON string or decoded map of the transcript data\n- `opts`: Options for the conversion:\n  - `:language`: (required for Deepgram) The language code of the transcript (e.g., \"en\", \"lt\")\n  - Other service-specific options","ref":"BoldTranscriptsEx.html#convert/3-parameters"},{"type":"function","title":"Returns - BoldTranscriptsEx.convert/3","doc":"- `{:ok, data}`: A tuple with `:ok` atom and the data in Bold Transcript format\n- `{:error, reason}`: If the conversion fails or required options are missing","ref":"BoldTranscriptsEx.html#convert/3-returns"},{"type":"function","title":"Examples - BoldTranscriptsEx.convert/3","doc":"iex> transcript = ~s({\"audio_duration\": 10.5, \"language_code\": \"en\", \"audio_url\": \"https://example.com/audio.mp3\", \"utterances\": []})\n    iex> BoldTranscriptsEx.convert(:assemblyai, transcript)\n    {:ok, %{\n      \"metadata\" => %{\n        \"duration\" => 10.5,\n        \"language\" => \"en\",\n        \"source_url\" => \"https://example.com/audio.mp3\",\n        \"speakers\" => %{},\n        \"source_model\" => \"\",\n        \"source_vendor\" => \"assemblyai\",\n        \"source_version\" => \"\",\n        \"transcription_date\" => nil,\n        \"version\" => \"2.0\"\n      },\n      \"utterances\" => []\n    }}","ref":"BoldTranscriptsEx.html#convert/3-examples"},{"type":"function","title":"BoldTranscriptsEx.generate_subtitles/1","doc":"Generates WebVTT subtitles from a Bold transcript.","ref":"BoldTranscriptsEx.html#generate_subtitles/1"},{"type":"function","title":"Parameters - BoldTranscriptsEx.generate_subtitles/1","doc":"- `transcript`: A Bold transcript in v2 format.","ref":"BoldTranscriptsEx.html#generate_subtitles/1-parameters"},{"type":"function","title":"Returns - BoldTranscriptsEx.generate_subtitles/1","doc":"A string containing the WebVTT subtitles with speaker labels.\nSpeaker labels are only shown for named speakers using the WebVTT   tag.\nSingle-letter speaker IDs (A, B, C) are not shown.","ref":"BoldTranscriptsEx.html#generate_subtitles/1-returns"},{"type":"function","title":"Examples - BoldTranscriptsEx.generate_subtitles/1","doc":"iex> transcript = %{\n    ...>   \"metadata\" => %{\"speakers\" => %{\"A\" => \"Jack Smith\"}},\n    ...>   \"utterances\" => [%{\"words\" => [%{\"start\" => 0.8, \"end\" => 1.2, \"word\" => \"Hello\", \"speaker\" => \"A\"}], \"speaker\" => \"A\"}]\n    ...> }\n    iex> BoldTranscriptsEx.generate_subtitles(transcript)\n    \"WEBVTT\\n\\n1\\n00:00:00.800 --> 00:00:01.200\\n Hello \"","ref":"BoldTranscriptsEx.html#generate_subtitles/1-examples"},{"type":"function","title":"BoldTranscriptsEx.parse_chapters/1","doc":"Parses WebVTT content to extract chapters.","ref":"BoldTranscriptsEx.html#parse_chapters/1"},{"type":"function","title":"Parameters - BoldTranscriptsEx.parse_chapters/1","doc":"- `webvtt`: The WebVTT content as a string.","ref":"BoldTranscriptsEx.html#parse_chapters/1-parameters"},{"type":"function","title":"Returns - BoldTranscriptsEx.parse_chapters/1","doc":"A list of maps, each containing `:start` and `:title` keys for a chapter.","ref":"BoldTranscriptsEx.html#parse_chapters/1-returns"},{"type":"function","title":"Examples - BoldTranscriptsEx.parse_chapters/1","doc":"iex> webvtt = \"WEBVTT\\n\\n1\\n00:00:03.000 --> 00:00:16.000\\nComing soon: Back to Stanford\"\n    iex> BoldTranscriptsEx.parse_chapters(webvtt)\n    [%{start: \"0:03\", end: \"0:16\", title: \"Coming soon: Back to Stanford\"}]","ref":"BoldTranscriptsEx.html#parse_chapters/1-examples"},{"type":"module","title":"BoldTranscriptsEx.Convert","doc":"","ref":"BoldTranscriptsEx.Convert.html"},{"type":"function","title":"BoldTranscriptsEx.Convert.chapters_to_webvtt/3","doc":"","ref":"BoldTranscriptsEx.Convert.html#chapters_to_webvtt/3"},{"type":"function","title":"BoldTranscriptsEx.Convert.chapters_webvtt_to_text/1","doc":"Converts a chapters WebVTT file to a text with one chapter per line and a short timestamp.","ref":"BoldTranscriptsEx.Convert.html#chapters_webvtt_to_text/1"},{"type":"function","title":"Example - BoldTranscriptsEx.Convert.chapters_webvtt_to_text/1","doc":"iex> Convert.chapters_webvtt_to_text(\"\"\"\n    ...> WEBVTT\n    ...>\n    ...> 1\n    ...> 00:00:00.000 --> 00:00:37.000\n    ...> Hello World\n    ...>\n    ...> 2\n    ...> 00:00:37.000 --> 00:01:59.000\n    ...> Introduction\n    ...> \"\"\")\n    \"00:00 Hello World\\n00:37 Introduction\"","ref":"BoldTranscriptsEx.Convert.html#chapters_webvtt_to_text/1-example"},{"type":"function","title":"BoldTranscriptsEx.Convert.from/3","doc":"Converts a transcript from a specific service to Bold format.","ref":"BoldTranscriptsEx.Convert.html#from/3"},{"type":"function","title":"Parameters - BoldTranscriptsEx.Convert.from/3","doc":"- `service`: The service that generated the transcript (e.g., `:assemblyai`, `:deepgram`)\n- `transcript_data`: The JSON string or decoded map of the transcript data\n- `opts`: Options for the conversion:\n  - `:language`: (required for Deepgram) The language code of the transcript (e.g., \"en\", \"lt\")\n  - Other service-specific options","ref":"BoldTranscriptsEx.Convert.html#from/3-parameters"},{"type":"function","title":"Returns - BoldTranscriptsEx.Convert.from/3","doc":"- `{:ok, data}`: A tuple with `:ok` atom and the data in Bold Transcript format\n- `{:error, reason}`: If the conversion fails or required options are missing","ref":"BoldTranscriptsEx.Convert.html#from/3-returns"},{"type":"function","title":"BoldTranscriptsEx.Convert.text_to_chapters_webvtt/2","doc":"Converts a text with one chapter per row into a WebVTT file.","ref":"BoldTranscriptsEx.Convert.html#text_to_chapters_webvtt/2"},{"type":"function","title":"Example - BoldTranscriptsEx.Convert.text_to_chapters_webvtt/2","doc":"iex> Convert.text_to_chapters_webvtt(\"\"\"\n    ...> 00:00 Hello World\n    ...> 01:59 The End\n    ...> \"\"\", 155)\n    \"WEBVTT\\n\\n1\\n00:00:00.000 --> 00:01:59.000\\nHello World\\n\\n2\\n00:01:59.000 --> 00:02:35.000\\nThe End\\n\\n\"","ref":"BoldTranscriptsEx.Convert.html#text_to_chapters_webvtt/2-example"},{"type":"module","title":"BoldTranscriptsEx.Convert.AssemblyAI","doc":"Handles conversion of AssemblyAI transcription files to Bold format.\n\nThis module provides functionality to:\n- Convert AssemblyAI transcripts to Bold format\n- Convert chapter data to WebVTT format\n- Handle both v1 and v2 of the Bold format","ref":"BoldTranscriptsEx.Convert.AssemblyAI.html"},{"type":"function","title":"BoldTranscriptsEx.Convert.AssemblyAI.chapters_to_webvtt/2","doc":"Converts chapter data from an AssemblyAI transcript to WebVTT format.","ref":"BoldTranscriptsEx.Convert.AssemblyAI.html#chapters_to_webvtt/2"},{"type":"function","title":"Parameters - BoldTranscriptsEx.Convert.AssemblyAI.chapters_to_webvtt/2","doc":"- `transcript`: The decoded transcript map containing chapter data.\n- `opts`: Optional parameters (unused for now, but included for future flexibility).","ref":"BoldTranscriptsEx.Convert.AssemblyAI.html#chapters_to_webvtt/2-parameters"},{"type":"function","title":"Returns - BoldTranscriptsEx.Convert.AssemblyAI.chapters_to_webvtt/2","doc":"- `{:ok, webvtt_string}` - Successfully converted chapters to WebVTT format\n- `{:error, reason}` - If no chapters are found or conversion fails","ref":"BoldTranscriptsEx.Convert.AssemblyAI.html#chapters_to_webvtt/2-returns"},{"type":"function","title":"Examples - BoldTranscriptsEx.Convert.AssemblyAI.chapters_to_webvtt/2","doc":"iex> transcript = %{\n    ...>   \"chapters\" => [\n    ...>     %{\n    ...>       \"start\" => 1000,\n    ...>       \"end\" => 5000,\n    ...>       \"gist\" => \"Introduction\"\n    ...>     }\n    ...>   ]\n    ...> }\n    iex> BoldTranscriptsEx.Convert.AssemblyAI.chapters_to_webvtt(transcript)\n    {:ok, \"WEBVTT\\n\\n1\\n00:00:01.000 --> 00:00:05.000\\nIntroduction\\n\"}","ref":"BoldTranscriptsEx.Convert.AssemblyAI.html#chapters_to_webvtt/2-examples"},{"type":"function","title":"BoldTranscriptsEx.Convert.AssemblyAI.transcript_to_bold/2","doc":"Converts an AssemblyAI transcript to the Bold Transcript format.","ref":"BoldTranscriptsEx.Convert.AssemblyAI.html#transcript_to_bold/2"},{"type":"function","title":"Parameters - BoldTranscriptsEx.Convert.AssemblyAI.transcript_to_bold/2","doc":"- `transcript`: The JSON string or decoded map of the transcript data from AssemblyAI.\n- `opts`: Options for the conversion:\n  - `:version`: The Bold format version to use (1 or 2). Defaults to 2.\n  - `:paragraphs`: Optional paragraphs data as JSON string.","ref":"BoldTranscriptsEx.Convert.AssemblyAI.html#transcript_to_bold/2-parameters"},{"type":"function","title":"Returns - BoldTranscriptsEx.Convert.AssemblyAI.transcript_to_bold/2","doc":"- `{:ok, bold_transcript}` - Successfully converted transcript where:\n  - `bold_transcript` is a map containing:\n    - `\"metadata\"` - Information about the transcript\n    - `\"utterances\"` - List of speech segments with timing\n    - `\"paragraphs\"` - (Optional) List of paragraph segments\n- `{:error, reason}` - If conversion fails","ref":"BoldTranscriptsEx.Convert.AssemblyAI.html#transcript_to_bold/2-returns"},{"type":"function","title":"Examples - BoldTranscriptsEx.Convert.AssemblyAI.transcript_to_bold/2","doc":"# Basic conversion\n    iex> json = ~s({\"audio_duration\": 10.5, \"language_code\": \"en\"})\n    iex> BoldTranscriptsEx.Convert.AssemblyAI.transcript_to_bold(json)\n    {:ok, %{\n      \"metadata\" => %{\n        \"duration\" => 10.5,\n        \"language\" => \"en\",\n        \"source_vendor\" => \"assemblyai\"\n      },\n      \"utterances\" => []\n    }}\n\n    # With version specified\n    iex> BoldTranscriptsEx.Convert.AssemblyAI.transcript_to_bold(json, version: 1)\n    {:ok, %{...}}","ref":"BoldTranscriptsEx.Convert.AssemblyAI.html#transcript_to_bold/2-examples"},{"type":"module","title":"BoldTranscriptsEx.Convert.Common","doc":"Conversion functions that are common to all providers.","ref":"BoldTranscriptsEx.Convert.Common.html"},{"type":"function","title":"BoldTranscriptsEx.Convert.Common.chapters_webvtt_to_text/1","doc":"Converts a chapters WebVTT into a text with one chapter and timestamp per line.","ref":"BoldTranscriptsEx.Convert.Common.html#chapters_webvtt_to_text/1"},{"type":"function","title":"BoldTranscriptsEx.Convert.Common.text_to_chapters_webvtt/2","doc":"Converts a text input to a chapters WebVTT text.\n\nExpects the input text and a total duration in Seconds.","ref":"BoldTranscriptsEx.Convert.Common.html#text_to_chapters_webvtt/2"},{"type":"module","title":"BoldTranscriptsEx.Convert.Deepgram","doc":"Handles conversion of Deepgram transcription files to Bold format.","ref":"BoldTranscriptsEx.Convert.Deepgram.html"},{"type":"function","title":"BoldTranscriptsEx.Convert.Deepgram.transcript_to_bold/2","doc":"Converts a Deepgram transcript to the Bold Transcript format.","ref":"BoldTranscriptsEx.Convert.Deepgram.html#transcript_to_bold/2"},{"type":"function","title":"Parameters - BoldTranscriptsEx.Convert.Deepgram.transcript_to_bold/2","doc":"- `transcript`: The JSON string or decoded map of the transcript data from Deepgram.\n- `opts`: Options for the conversion:\n  - `:language`: (required) The language code of the transcript (e.g., \"en\", \"lt\")","ref":"BoldTranscriptsEx.Convert.Deepgram.html#transcript_to_bold/2-parameters"},{"type":"function","title":"Returns - BoldTranscriptsEx.Convert.Deepgram.transcript_to_bold/2","doc":"- `{:ok, merged_data}`: A tuple with `:ok` atom and the data in Bold Transcript format.\n- `{:error, reason}`: If required options are missing.","ref":"BoldTranscriptsEx.Convert.Deepgram.html#transcript_to_bold/2-returns"},{"type":"function","title":"Examples - BoldTranscriptsEx.Convert.Deepgram.transcript_to_bold/2","doc":"iex> BoldTranscriptsEx.Convert.Deepgram.transcript_to_bold(transcript, language: \"lt\")\n    {:ok, %{\"metadata\" => metadata, \"utterances\" => utterances, \"paragraphs\" => paragraphs}}","ref":"BoldTranscriptsEx.Convert.Deepgram.html#transcript_to_bold/2-examples"},{"type":"module","title":"BoldTranscriptsEx.Convert.Speechmatics","doc":"Handles conversion of Speechmatics transcription files to Bold format.","ref":"BoldTranscriptsEx.Convert.Speechmatics.html"},{"type":"function","title":"BoldTranscriptsEx.Convert.Speechmatics.transcript_to_bold/1","doc":"","ref":"BoldTranscriptsEx.Convert.Speechmatics.html#transcript_to_bold/1"},{"type":"module","title":"BoldTranscriptsEx.Test","doc":"Test helper module for quick testing in IEx","ref":"BoldTranscriptsEx.Test.html"},{"type":"function","title":"BoldTranscriptsEx.Test.test/0","doc":"","ref":"BoldTranscriptsEx.Test.html#test/0"},{"type":"module","title":"BoldTranscriptsEx.Utils","doc":"","ref":"BoldTranscriptsEx.Utils.html"},{"type":"function","title":"BoldTranscriptsEx.Utils.format_chapter_timestamp/2","doc":"Formats a duration from millisecond or seconds to a chapter timestamp like `01:12:34.000`\nwith `HH:MM:SS.000` format (hour, minutes, seconds).\n\nThe second parameter indicates whether the given number is in milliseconds or seconds.","ref":"BoldTranscriptsEx.Utils.html#format_chapter_timestamp/2"},{"type":"function","title":"BoldTranscriptsEx.Utils.maybe_decode/1","doc":"Decodes a binary into json if necessary.","ref":"BoldTranscriptsEx.Utils.html#maybe_decode/1"},{"type":"function","title":"BoldTranscriptsEx.Utils.pad/2","doc":"","ref":"BoldTranscriptsEx.Utils.html#pad/2"},{"type":"module","title":"BoldTranscriptsEx.Utils.Chapters","doc":"Provides utility functions for working with chapter data.\n\nThis module handles:\n- Converting between different chapter formats\n- Parsing WebVTT chapter files\n- Converting chapters to WebVTT format\n- Time format conversions (WebVTT, milliseconds, human-readable)\n\nChapter data can be represented in different formats:\n- WebVTT format (text with timestamps and titles)\n- Bold format (list of maps with start/end times and titles)\n- AssemblyAI format (embedded in transcript with gist as title)","ref":"BoldTranscriptsEx.Utils.Chapters.html"},{"type":"function","title":"BoldTranscriptsEx.Utils.Chapters.chapters_to_webvtt/1","doc":"Converts a list of chapters into WebVTT format.","ref":"BoldTranscriptsEx.Utils.Chapters.html#chapters_to_webvtt/1"},{"type":"function","title":"Parameters - BoldTranscriptsEx.Utils.Chapters.chapters_to_webvtt/1","doc":"- `chapters`: A list of maps, each containing:\n  - `:start` - Start time as \"MM:SS\" or \"HH:MM:SS\"\n  - `:end` - End time in same format as start\n  - `:title` - Chapter title","ref":"BoldTranscriptsEx.Utils.Chapters.html#chapters_to_webvtt/1-parameters"},{"type":"function","title":"Returns - BoldTranscriptsEx.Utils.Chapters.chapters_to_webvtt/1","doc":"A string in WebVTT format with chapter markers.","ref":"BoldTranscriptsEx.Utils.Chapters.html#chapters_to_webvtt/1-returns"},{"type":"function","title":"Examples - BoldTranscriptsEx.Utils.Chapters.chapters_to_webvtt/1","doc":"iex> chapters = [\n    ...>   %{start: \"0:03\", end: \"0:16\", title: \"Introduction\"},\n    ...>   %{start: \"0:16\", end: \"1:00\", title: \"Main Content\"}\n    ...> ]\n    iex> BoldTranscriptsEx.Utils.Chapters.chapters_to_webvtt(chapters)\n    \"\"\"\n    WEBVTT\n\n    1\n    00:00:03.000 --> 00:00:16.000\n    Introduction\n\n    2\n    00:00:16.000 --> 00:01:00.000\n    Main Content\n    \"\"\"","ref":"BoldTranscriptsEx.Utils.Chapters.html#chapters_to_webvtt/1-examples"},{"type":"function","title":"BoldTranscriptsEx.Utils.Chapters.chapters_to_webvtt/2","doc":"","ref":"BoldTranscriptsEx.Utils.Chapters.html#chapters_to_webvtt/2"},{"type":"function","title":"BoldTranscriptsEx.Utils.Chapters.ms_to_webvtt/1","doc":"Converts milliseconds to WebVTT timestamp format (HH:MM:SS.mmm)","ref":"BoldTranscriptsEx.Utils.Chapters.html#ms_to_webvtt/1"},{"type":"function","title":"Examples - BoldTranscriptsEx.Utils.Chapters.ms_to_webvtt/1","doc":"iex> ms_to_webvtt(114160)\n    \"00:01:54.160\"\n\n    iex> ms_to_webvtt(5000)\n    \"00:00:05.000\"","ref":"BoldTranscriptsEx.Utils.Chapters.html#ms_to_webvtt/1-examples"},{"type":"function","title":"BoldTranscriptsEx.Utils.Chapters.parse_chapters/1","doc":"Parses WebVTT content to extract chapters, converting them into a structured list.","ref":"BoldTranscriptsEx.Utils.Chapters.html#parse_chapters/1"},{"type":"function","title":"Parameters - BoldTranscriptsEx.Utils.Chapters.parse_chapters/1","doc":"- `webvtt`: The WebVTT content as a string in format:\n  ```\n  WEBVTT\n\n  1\n  00:00:03.000 --> 00:00:16.000\n  Chapter Title\n  ```","ref":"BoldTranscriptsEx.Utils.Chapters.html#parse_chapters/1-parameters"},{"type":"function","title":"Returns - BoldTranscriptsEx.Utils.Chapters.parse_chapters/1","doc":"A list of maps, each containing:\n- `:start` - Start time in format \"MM:SS\" or \"HH:MM:SS\"\n- `:end` - End time in same format as start\n- `:title` - Chapter title as string","ref":"BoldTranscriptsEx.Utils.Chapters.html#parse_chapters/1-returns"},{"type":"function","title":"Examples - BoldTranscriptsEx.Utils.Chapters.parse_chapters/1","doc":"iex> webvtt = \"\"\"\n    ...> WEBVTT\n    ...>\n    ...> 1\n    ...> 00:00:03.000 --> 00:00:16.000\n    ...> Introduction\n    ...> \"\"\"\n    iex> BoldTranscriptsEx.Utils.Chapters.parse_chapters(webvtt)\n    [%{start: \"0:03\", end: \"0:16\", title: \"Introduction\"}]","ref":"BoldTranscriptsEx.Utils.Chapters.html#parse_chapters/1-examples"},{"type":"module","title":"BoldTranscriptsEx.WebVTT","doc":"Provides functionality for working with WebVTT files.\n\nThis module handles:\n- Converting Bold transcripts to WebVTT subtitles\n- Smart subtitle splitting based on word timing and natural pauses\n- Line length optimization for readability\n- Speaker identification in subtitles using WebVTT's   tag\n\nConfiguration:\n- Maximum 42 characters per line\n- Maximum 2 lines per subtitle\n- Natural breaks at pauses longer than 0.15s\n- 0.0s gap between subtitles for better readability","ref":"BoldTranscriptsEx.WebVTT.html"},{"type":"function","title":"BoldTranscriptsEx.WebVTT.generate_subtitles/1","doc":"Generates WebVTT subtitles from a Bold transcript.","ref":"BoldTranscriptsEx.WebVTT.html#generate_subtitles/1"},{"type":"function","title":"Parameters - BoldTranscriptsEx.WebVTT.generate_subtitles/1","doc":"- `transcript`: A Bold transcript map containing:\n  - `metadata.speakers` - Map of speaker IDs to names\n  - `utterances` - List of utterances with word-level timing","ref":"BoldTranscriptsEx.WebVTT.html#generate_subtitles/1-parameters"},{"type":"function","title":"Returns - BoldTranscriptsEx.WebVTT.generate_subtitles/1","doc":"A string containing the WebVTT subtitles with speaker labels.","ref":"BoldTranscriptsEx.WebVTT.html#generate_subtitles/1-returns"},{"type":"function","title":"Examples - BoldTranscriptsEx.WebVTT.generate_subtitles/1","doc":"iex> transcript = %{\n    ...>   \"metadata\" => %{\"speakers\" => %{\"A\" => \"John\"}},\n    ...>   \"utterances\" => [\n    ...>     %{\n    ...>       \"start\" => 0.0,\n    ...>       \"end\" => 2.5,\n    ...>       \"text\" => \"Hello world\",\n    ...>       \"speaker\" => \"A\",\n    ...>       \"words\" => [\n    ...>         %{\"word\" => \"Hello\", \"start\" => 0.0, \"end\" => 1.0},\n    ...>         %{\"word\" => \"world\", \"start\" => 1.5, \"end\" => 2.5}\n    ...>       ]\n    ...>     }\n    ...>   ]\n    ...> }\n    iex> BoldTranscriptsEx.WebVTT.generate_subtitles(transcript)\n    \"WEBVTT\\n\\n1\\n00:00:00.000 --> 00:00:02.300\\n Hello world \"","ref":"BoldTranscriptsEx.WebVTT.html#generate_subtitles/1-examples"},{"type":"module","title":"BoldTranscriptsEx.WebVTT2","doc":"","ref":"BoldTranscriptsEx.WebVTT2.html"},{"type":"function","title":"BoldTranscriptsEx.WebVTT2.create/1","doc":"","ref":"BoldTranscriptsEx.WebVTT2.html#create/1"},{"type":"function","title":"BoldTranscriptsEx.WebVTT2.process_line/1","doc":"","ref":"BoldTranscriptsEx.WebVTT2.html#process_line/1"},{"type":"extras","title":"Bold Transcripts","doc":"# Bold Transcripts\n\n[![Hex.pm](https://img.shields.io/hexpm/v/bold_transcripts_ex.svg)](https://hex.pm/packages/bold_transcripts_ex)\n[![Hex.pm](https://img.shields.io/hexpm/dt/bold_transcripts_ex.svg)](https://hex.pm/packages/bold_transcripts_ex)\n\nA simple Elixir library for working with [Bold Video](https://bold.video) transcripts. Convert transcripts from various providers (AssemblyAI, Deepgram) to Bold's unified transcript format, and generate WebVTT subtitles.","ref":"readme.html"},{"type":"extras","title":"Installation - Bold Transcripts","doc":"Add `bold_transcripts_ex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:bold_transcripts_ex, \"~> 0.6.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - Bold Transcripts","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Converting Transcripts - Bold Transcripts","doc":"Convert transcripts from supported providers to Bold format:\n\n```elixir\n# Convert from AssemblyAI\n{:ok, bold_transcript} = BoldTranscriptsEx.convert(:assemblyai, assemblyai_json)\n\n# Convert from Deepgram\n{:ok, bold_transcript} = BoldTranscriptsEx.convert(:deepgram, deepgram_json, language: \"en\")\n```","ref":"readme.html#converting-transcripts"},{"type":"extras","title":"Generating Subtitles - Bold Transcripts","doc":"Create WebVTT subtitles from a Bold transcript:\n\n```elixir\nwebvtt = BoldTranscriptsEx.generate_subtitles(bold_transcript)\n```","ref":"readme.html#generating-subtitles"},{"type":"extras","title":"Working with Chapters - Bold Transcripts","doc":"Convert chapters to WebVTT format:\n\n```elixir\n# From AssemblyAI transcript\n{:ok, chapters_vtt} = BoldTranscriptsEx.chapters_to_webvtt(:assemblyai, transcript)\n\n# From a list of chapters\nchapters_vtt = BoldTranscriptsEx.chapters_to_webvtt([\n  %{start: \"0:00\", end: \"1:30\", title: \"Introduction\"},\n  %{start: \"1:30\", end: \"5:45\", title: \"Main Content\"}\n])\n```","ref":"readme.html#working-with-chapters"},{"type":"extras","title":"Bold Transcript Format - Bold Transcripts","doc":"The Bold transcript format is a unified JSON structure that combines metadata and utterances as segments of speech:\n\n```json\n{\n  \"metadata\": {\n    \"version\": \"2.0\",\n    \"duration\": 34.789,\n    \"language\": \"en\",\n    \"source_url\": \"\",\n    \"source_vendor\": \"assemblyai\",\n    \"source_version\": \"1.2.3\",\n    \"transcription_date\": \"2024-12-19T12:00:00Z\",\n    \"speakers\": [\"A\", \"B\", \"C\"]\n  },\n  \"text\": \"Hey, how are you?\",\n  \"utterances\": [\n    {\n      \"text\": \"Hey, how are you?\",\n      \"start\": 0.64,\n      \"end\": 1.84,\n      \"speaker\": \"A\",\n      \"confidence\": 0.98789,\n      \"words\": [\n        {\n          \"word\": \"Hey\",\n          \"start\": 0.64,\n          \"end\": 0.84,\n          \"confidence\": 0.951\n        },\n        {\n          \"word\": \"how\",\n          \"start\": 0.85,\n          \"end\": 1.04,\n          \"confidence\": 0.962\n        },\n        {\n          \"word\": \"are\",\n          \"start\": 1.05,\n          \"end\": 1.24,\n          \"confidence\": 0.981\n        },\n        {\n          \"word\": \"you?\",\n          \"start\": 1.25,\n          \"end\": 1.84,\n          \"confidence\": 0.99\n        }\n      ]\n    }\n  ]\n}\n```","ref":"readme.html#bold-transcript-format"},{"type":"extras","title":"License - Bold Transcripts","doc":"This project is licensed under the MIT License. See the LICENSE file for details.","ref":"readme.html#license"},{"type":"extras","title":"Links - Bold Transcripts","doc":"- [Bold Video](https://bold.video)\n- [Documentation](https://hexdocs.pm/bold_transcripts_ex)\n- [GitHub](https://github.com/bold-app/bold_transcripts_ex)","ref":"readme.html#links"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.35.1"}}